#include <stdio.h>
#include <string.h>

#include "AlarmPOD.h"

AlarmPOD::AlarmPOD() : POD()
{
#if (DEBUG_OBJECTS)
   printf("In AlarmPOD ()\n");
#endif
   PODType = POD_TYPE_ALARM;
}

AlarmPOD::AlarmPOD(int DeviceNum,int PortNum) : POD(DeviceNum, PortNum)
{
#if (DEBUG_OBJECTS)
   printf("In AlarmPOD (%d, %d)\n", DeviceNum, PortNum);
#endif
   if (PODType != POD_TYPE_ALARM) printf("I'm not that type of POD\n");
}

AlarmPOD::AlarmPOD(int DeviceNum) : POD(DeviceNum)
{
#if (DEBUG_OBJECTS)
   printf("In AlarmPOD (%d)\n", DeviceNum);
#endif
   if (PODType != POD_TYPE_ALARM) printf("I'm not that type of POD\n");
}

int AlarmPOD::Test()
{
   int Result;
   int TempDuration;
   unsigned char Data[10];
   int Response;

   printf("Testing an alarm POD\n");
   TempDuration = ((int)(10)) & 0xFF;

   SendCommand(POD_COMMAND_ALARM_SOUND);
   SendByte(TempDuration);
   Result = ReceiveBytes(0x01, Data);
   Response = Data[0];
   if (Response == POD_RESPONSE_ACK) return(POD_ERROR_NONE);
   return(POD_ERROR_BADRESPONSE);
//   return(0);
}

int AlarmPOD::Sound(float Duration)
{
   int Result;
   int TempDuration;
   unsigned char Data[10];
   int Response;

   TempDuration = ((int)(Duration * 100)) & 0xFF;

   SendCommand(POD_COMMAND_ALARM_SOUND);
   SendByte(TempDuration);
   Result = ReceiveBytes(0x01, Data);
   Response = Data[0];
   if (Response == POD_RESPONSE_ACK) return(POD_ERROR_NONE);
   return(POD_ERROR_BADRESPONSE);
}

int AlarmPOD::SetMorseSpeed(char Speed)
{
   int Result;
   unsigned char Data[10];
   int Response;

   SendCommand(POD_COMMAND_ALARM_SET_MORSE_SPEED);
   SendByte(Speed);
   Result = ReceiveBytes(0x01, Data);
   Response = Data[0];
   if (Response == POD_RESPONSE_ACK) return(POD_ERROR_NONE);
   return(POD_ERROR_BADRESPONSE);
}

int AlarmPOD::SetMorseTone(char Tone)
{
   int Result;
   unsigned char Data[10];
   int Response;

   SendCommand(POD_COMMAND_ALARM_SET_MORSE_TONE);
   SendByte(Tone);
   Result = ReceiveBytes(0x01, Data);
   Response = Data[0];
   if (Response == POD_RESPONSE_ACK) return(POD_ERROR_NONE);
   return(POD_ERROR_BADRESPONSE);
}

int AlarmPOD::PlayMorse(char *String)
{
   int Result;
   unsigned char Data[10];
   int Response;
   int Counter;
   int StringLength;

   SendCommand(POD_COMMAND_ALARM_PLAY_MORSE);
   StringLength = strlen(String);
   SendByte(StringLength);
   for (Counter = 0 ; Counter < StringLength ; Counter ++)
   {
      SendByte(String[Counter]);
   }
   Result = ReceiveBytes(0x01, Data);
   Response = Data[0];
   if (Response == POD_RESPONSE_ACK) return(POD_ERROR_NONE);
   return(POD_ERROR_BADRESPONSE);
}

int AlarmPOD::Quiet()
{
   int Result;
   unsigned char Data[10];
   int Response;

   SendCommand(POD_COMMAND_ALARM_QUIET);
   Result = ReceiveBytes(0x01, Data);
   Response = Data[0];
   if (Response == POD_RESPONSE_ACK) return(POD_ERROR_NONE);
   return(POD_ERROR_BADRESPONSE);
}

