#include <stdio.h>
#include <unistd.h>

#include "LightPOD.h"

LightPOD::LightPOD() : POD()
{
#if (DEBUG_OBJECTS)
   printf("In LightPOD ()\n");
#endif
   PODType = POD_TYPE_LIGHT;
}

LightPOD::LightPOD(int DeviceNum,int PortNum) : POD(DeviceNum, PortNum)
{
#if (DEBUG_OBJECTS)
   printf("In LightPOD (%d, %d)\n", DeviceNum, PortNum);
#endif
   if (PODType != POD_TYPE_LIGHT) printf("I'm not that type of POD\n");
}

LightPOD::LightPOD(int DeviceNum) : POD(DeviceNum)
{
#if (DEBUG_OBJECTS)
   printf("In LightPOD (%d)\n", DeviceNum);
#endif
   if (PODType != POD_TYPE_LIGHT) printf("I'm not that type of POD\n");
}

int LightPOD::Test()
{
   int Counter;

   printf("Testing the lights.");
   for (Counter = 0 ; Counter < 16 ; Counter ++)
   {
      printf(".");
      TurnOn(Counter & 0x08, Counter & 0x04, Counter & 0x02, Counter & 0x01);
      usleep(250000);
   }
   AllOff();
   printf("Done\n");
   return(0);
}

int LightPOD::AllOn()
{
   return(TurnOn(1,1,1,1));
}

int LightPOD::AllOff()
{
   return(TurnOn(0,0,0,0));
}

int LightPOD::TurnOn(int LED1, int LED2, int LED3, int LED4)
{
   int Result;
   unsigned char Data[10];
   int Response;

   SendCommand(POD_COMMAND_LIGHT_ON);
   Data[0] = (LED1 ? 0x08 : 0x00) | (LED2 ? 0x04 : 0x00)
      | (LED3 ? 0x02 : 0x00) | (LED4 ? 0x01 : 0x00);
   Result = SendByte(Data[0]);
   Result = ReceiveBytes(0x01, Data);
   Response = Data[0];
   if (Response == POD_RESPONSE_ACK) return(POD_ERROR_NONE);
   return(POD_ERROR_BADRESPONSE);
}

int LightPOD::GetStatus(int LEDNumber)
{
   int Result;
   unsigned char Data[10];
   int Response;
   unsigned char ReturnData;

   SendCommand(POD_COMMAND_LIGHT_GET_STATUS);
   Result = ReceiveBytes(0x02, Data);
   Response = Data[0];

   if (Response != POD_RESPONSE_ACK) return(POD_ERROR_BADRESPONSE);

   ReturnData = ((Data[1] & 0x01) << 3)
      | ((Data[1] & 0x02) << 1)
      | ((Data[1] & 0x04) >> 1)
      | ((Data[1] & 0x08) >> 3);
   ReturnData = (~ReturnData) & 0x0F;
   if (LEDNumber == 0x0F) return(ReturnData);
   return(ReturnData & (1 << LEDNumber));
}

