#include <stdio.h>

#include "LightSensorPOD.h"

LightSensorPOD::LightSensorPOD() : POD()
{
#if (DEBUG_OBJECTS)
   printf("In LightSensorPOD ()\n");
#endif
   PODType = POD_TYPE_LIGHTSENSOR;
}

LightSensorPOD::LightSensorPOD(int DeviceNum,int PortNum) : POD(DeviceNum, PortNum)
{
#if (DEBUG_OBJECTS)
   printf("In LightSensorPOD (int, int)\n");
#endif
   if (PODType != POD_TYPE_LIGHTSENSOR) printf("I'm not that type of POD\n");
}

LightSensorPOD::LightSensorPOD(int DeviceNum) : POD(DeviceNum)
{
#if (DEBUG_OBJECTS)
   printf("In LightSensorPOD (int)\n");
#endif
   if (PODType != POD_TYPE_LIGHTSENSOR) printf("I'm not that type of POD\n");
}

int LightSensorPOD::Test()
{
   printf("My Reading is %d\n", GetIntensity());
   printf("With a threshold of %d, the light is %d\n", GetThreshold(), IsLightOn());
   return(0);
}

int LightSensorPOD::GetIntensity()
{
   int Result;
   unsigned char Data[10];
   int Response;

   SendCommand(POD_COMMAND_LIGHTSENSOR_GET_INTENSITY);
   Result = ReceiveBytes(0x03, Data);
   Response = Data[0];
   if (Response == POD_RESPONSE_ACK) return((Data[1] << 8) | Data[2]);
   return(POD_ERROR_BADRESPONSE);
}

int LightSensorPOD::GetThreshold()
{
   int Result;
   unsigned char Data[10];
   int Response;
   SendCommand(POD_COMMAND_LIGHTSENSOR_GET_THRESHOLD);
   Result = ReceiveBytes(0x03, Data);
   Response = Data[0];
   if (Response == POD_RESPONSE_ACK) return((Data[1] << 8) | Data[2]);
   return(POD_ERROR_BADRESPONSE);
}

int LightSensorPOD::SetThreshold(int Threshold)
{
   int Result;
   unsigned char Data[10];
   int Response;
   SendCommand(POD_COMMAND_LIGHTSENSOR_SET_THRESHOLD);
   Result = SendBytes(2, Threshold);
   Result = ReceiveBytes(0x01, Data);
   Response = Data[0];
   if (Response == POD_RESPONSE_ACK) return(POD_ERROR_NONE);
   return(POD_ERROR_BADRESPONSE);
}

int LightSensorPOD::IsLightOn()
{
   int Result;
   unsigned char Data[10];
   int Response;
   SendCommand(POD_COMMAND_LIGHTSENSOR_IS_LIGHT_ON);
   Result = ReceiveBytes(0x02, Data);
   Response = Data[0];
   if (Response == POD_RESPONSE_ACK) return(Data[1]);
   return(POD_ERROR_BADRESPONSE);
}


