#include <stdio.h>
#include <unistd.h>

#include "MotorControlPOD.h"

MotorControlPOD::MotorControlPOD() : POD()
{
#if (DEBUG_OBJECTS)
   printf("In MotorControlPOD ()\n");
#endif
   PODType = POD_TYPE_MOTORCONTROL;
}

MotorControlPOD::MotorControlPOD(int DeviceNum,int PortNum) : POD(DeviceNum, PortNum)
{
#if (DEBUG_OBJECTS)
   printf("In MotorControlPOD (%d, %d)\n", DeviceNum, PortNum);
#endif
   if (PODType != POD_TYPE_MOTORCONTROL) printf("I'm not that type of POD\n");
}

MotorControlPOD::MotorControlPOD(int DeviceNum) : POD(DeviceNum)
{
#if (DEBUG_OBJECTS)
   printf("In MotorControlPOD (%d)\n", DeviceNum);
#endif
   if (PODType != POD_TYPE_MOTORCONTROL) printf("I'm not that type of POD\n");
}

int MotorControlPOD::Test()
{
   Clockwise_Slow(); /* ahead */
   sleep(2);
   SetSpeed(0); /* stop */
   sleep(2);
   CounterClockwise_Slow(); /* backwards */
   sleep(2);
   SetSpeed(255); /* really fast */
   sleep(2);
   Stop();
   return(0);
}

int MotorControlPOD::Stop()
{
   int Result;
   unsigned char Data[10];
   int Response;

   SendCommand(POD_COMMAND_MOTORCONTROL_STOP);
   Result = ReceiveBytes(0x01, Data);
   Response = Data[0];
   if (Response == POD_RESPONSE_ACK) return(POD_ERROR_NONE);
   return(POD_ERROR_BADRESPONSE);
}

int MotorControlPOD::Clockwise(unsigned char Speed)
{
   int Result;
   unsigned char Data[10];
   int Response;

   SendCommand(POD_COMMAND_MOTORCONTROL_SET_DIR);
   SendByte(0);
   Result = ReceiveBytes(0x01, Data);
   Response = Data[0];

   SetSpeed(Speed);

   if (Response == POD_RESPONSE_ACK) return(POD_ERROR_NONE);
   return(POD_ERROR_BADRESPONSE);
}

int MotorControlPOD::Clockwise_Slow()
{
   int Result;

   Clockwise(80);
//   Result = SetSpeed(80);
   return(Result);
}

int MotorControlPOD::CounterClockwise(unsigned char Speed)
{
   int Result;
   unsigned char Data[10];
   int Response;

   SendCommand(POD_COMMAND_MOTORCONTROL_SET_DIR);
   SendByte(1);
   Result = ReceiveBytes(0x01, Data);
   Response = Data[0];

   SetSpeed(Speed);

   if (Response == POD_RESPONSE_ACK) return(POD_ERROR_NONE);
   return(POD_ERROR_BADRESPONSE);
}

int MotorControlPOD::CounterClockwise_Slow()
{
   int Result;

   CounterClockwise(80);
   return(Result);
}  


int MotorControlPOD::SetSpeed(unsigned char Speed)
{
   int Result;
   unsigned char Data[10];
   int Response;

   SendCommand(POD_COMMAND_MOTORCONTROL_SET_SPEED);
   SendByte(Speed);
   Result = ReceiveBytes(0x01, Data);
   Response = Data[0];
   if (Response == POD_RESPONSE_ACK) return(POD_ERROR_NONE);
   return(POD_ERROR_BADRESPONSE);
}

int MotorControlPOD::SetDirection(int Direction)
{
   int Result;
   unsigned char Data[10];
   int Response;

   SendCommand(POD_COMMAND_MOTORCONTROL_SET_DIR);
   if (Direction == MOTOR_DIRECTION_COUNTERCLOCKWISE)
      SendByte(1);
   else SendByte(0);

   Result = ReceiveBytes(0x01, Data);
   Response = Data[0];
   if (Response == POD_RESPONSE_ACK) return(POD_ERROR_NONE);
   return(POD_ERROR_BADRESPONSE);
}



