#ifndef __POD_H__
#define __POD_H__

#include <termios.h>

#include "PODDefines.h"

class POD
{
   private:
      int Port; /* to store the port */
      struct termios OrigTermIO; /* store the original configuration of the terminal */
      char *DeviceFile; /* the character device */
      int DeviceNumber; /* the number of the device */
      int Valid;
      char *Version; /* Version/Date information for the POD */
      char *URL; /* the URL for additional information on the POD */
      int SetTerminalSettings();
      int OpenDevice();
      int SetDeviceFile(int DeviceNum);
      int DetectPODType();
   protected:
      int PODType;
      int SendBytes(int Length, unsigned char *Data);
      int SendByte(unsigned char Data);
      int SendBytes(int Length, int Data);
      int ReceiveBytes(int Length, unsigned char *Data);
      int SendCommand(unsigned int Command);
      int GetInfo();
   public:
      int ReceiveReady();
      POD(int DeviceNum, int PortNum); /* called when PODEnv has already opened the device */
      POD(int DeviceNum); /* this constructor will open DeviceNum */
      POD();
      int GetPort();
      int GetDeviceNumber();
      int GetType();
      int GetType(char *PODTypeString);
      int GetURL(char *ReturnURL);
      int GetVersion(char *ReturnVersion);
      int GetName(char *ReturnName);
      int SetName(char *NewName);
      virtual ~POD();
      int TestMirror(int Count); /* just used for debugging */
      int Ping();
      int TestConnection();
      void DisplayPODInfo();
      int IsValid();
      virtual int Test();
};

#endif /* __POD_H__ */
