#ifndef __POD_DEFINES_H__
#define __POD_DEFINES_H__

/* POD Type IDs */
#define POD_TYPE_NONE         0x0000
#define POD_TYPE_THERMOMETER  0x0001
#define POD_TYPE_ALARM        0x0002
#define POD_TYPE_MOTORCONTROL 0x0003
#define POD_TYPE_LIGHTSENSOR  0x0004
#define POD_TYPE_LIGHT        0x0005
#define POD_TYPE_POWERSENSOR  0x0006
#define POD_TYPE_COMPASS      0x0007
#define POD_TYPE_DISTANCE     0x0008
#define POD_TYPE_BUTTONS      0x0009
#define POD_TYPE_UNKNOWN      0xFFFF

/* The max length of a POD Type name (such as Thermometer) */
#define POD_SIZE_TYPENAME     0x0020

/* The max length of a POD URL */
#define POD_SIZE_URL          0x0030

/* The max length of a POD Name (such as Outside) */
#define POD_SIZE_NAME         0x0010

/* General POD Commands */
#define POD_COMMAND_PING      0x0000
#define POD_COMMAND_GETTYPE   0x0001
#define POD_COMMAND_GETINFO   0x0002
#define POD_COMMAND_RESET     0x0003
#define POD_COMMAND_GETNAME   0x0004
#define POD_COMMAND_SETNAME   0x0005

/* General POD Responses */
#define POD_RESPONSE_PONG     0x0000
#define POD_RESPONSE_ACK      0x0001
#define POD_RESPONSE_ALERT    0x0002
#define POD_RESPONSE_NACK     0x0003

/* POD object error responses (from object functions, not from the POD itself) */
#define POD_ERROR_NONE        0
#define POD_ERROR_WRONGTYPE   -1
#define POD_ERROR_BADDEVICE   -2
#define POD_ERROR_COMM        -3
#define POD_ERROR_BADRESPONSE -4


/* EEPROM locations and lengths for General POD information */
#define POD_EEPROM_LEN        0x0200

#define POD_EEPROM_NAME_ADDR  0x0000
#define POD_EEPROM_NAME_LEN   POD_SIZE_NAME

#define POD_EEPROM_URL_ADDR   0x0010
#define POD_EEPROM_URL_LEN    POD_SIZE_URL

#define POD_EEPROM_FREE_ADDR  0x0040


/* Thermometer POD definitions */
#define POD_COMMAND_THERMOMETER_GET_TEMP  0x0100
#define POD_COMMAND_THERMOMETER_GET_UNITS 0x0101
#define POD_COMMAND_THERMOMETER_SET_UNITS 0x0102
#define POD_COMMAND_THERMOMETER_SET_WARN  0x0103
#define POD_COMMAND_THERMOMETER_GET_WARN  0x0104

#define POD_ALERT_THERMOMETER_TEMP_OKAY   0x0000
#define POD_ALERT_THERMOMETER_TEMP_HIGH   0x0001
#define POD_ALERT_THERMOMETER_TEMP_LOW    0x0002

/* LightSensor POD definitions */
#define POD_COMMAND_LIGHTSENSOR_GET_INTENSITY 0x0100
#define POD_COMMAND_LIGHTSENSOR_GET_THRESHOLD 0x0101
#define POD_COMMAND_LIGHTSENSOR_SET_THRESHOLD 0x0102
#define POD_COMMAND_LIGHTSENSOR_IS_LIGHT_ON   0x0103

/* PowerSensor POD definitions */
#define POD_COMMAND_POWERSENSOR_GET_STATUS    0x0100

/* Compass POD definitions */
#define POD_COMMAND_COMPASS_GET_HEADING       0x0100

/* Sonar POD Definitions */
#define POD_COMMAND_DISTANCE_GET_INCHES       0x0100
#define POD_COMMAND_DISTANCE_GET_CM           0x0101
#define POD_COMMAND_DISTANCE_GET_USEC         0x0102

/* LED Light POD Definitions */
#define POD_COMMAND_LIGHT_ON                  0x0100
#define POD_COMMAND_LIGHT_GET_STATUS          0x0101

/* MotorControl POD Definitions */
#define POD_COMMAND_MOTORCONTROL_STOP         0x0100
#define POD_COMMAND_MOTORCONTROL_SET_DIR      0x0101
#define POD_COMMAND_MOTORCONTROL_SET_SPEED    0x0102
//#define POD_COMMAND_MOTORCONTROL_SET_SPEED    0x0100

/* Alarm POD Definitions */
#define POD_COMMAND_ALARM_SET_MORSE_SPEED     0x0100
#define POD_COMMAND_ALARM_SET_MORSE_TONE      0x0101
#define POD_COMMAND_ALARM_PLAY_MORSE          0x0102
#define POD_COMMAND_ALARM_QUIET               0x0104
#define POD_COMMAND_ALARM_SOUND               0x0105
//#define POD_COMMAND_ALARM_SET_MORSE_SPEED     0x0103
//#define POD_COMMAND_ALARM_SET_MORSE_SPEED     0x0100

/* Buttons POD Deinitions */
#define POD_COMMAND_BUTTONS_GET_STATUS        0x0100
#define POD_COMMAND_BUTTONS_GET_NUMBER        0x0101


/* PODEnv Definitions */
#define POD_ENV_OPTION_NONE                   0x0000
#define POD_ENV_OPTION_TEXT_STATUS            0x0001
#define POD_ENV_OPTION_GUI_STATUS             0x0002
#define POD_ENV_OPTION_DONT_INIT              0x0004



#endif /* ifndef __POD_DEFINES_H__ */
