#include <stdio.h>
#include <string.h>
#include <unistd.h>

#if INCLUDE_GUI
#include <gtk/gtk.h>
#include <glib.h>

extern void g_free (gpointer mem);

#endif

#include "PODEnv.h"

PODEnv::PODEnv(int _Options)
{
   int Counter;
   int ShouldInitialize = 1;

   Options = _Options;
   if (Options & POD_ENV_OPTION_DONT_INIT) ShouldInitialize = 0;
   NumberOfPODs = 0;

   for (Counter = 0 ; Counter < MAXPODS ; Counter ++) PODs[Counter] = NULL;

   if (ShouldInitialize)
   {
      RefreshPODs();
   }
   else
   {
      if (Options & POD_ENV_OPTION_TEXT_STATUS)
      {
         printf("Not initializing POD list\n");
         fflush(stdout);
      }
   }
}

int PODEnv::GetNumberOfPODs()
{
   return(NumberOfPODs);
}

int PODEnv::GetAllPODs(POD **ReturnPODList)
{
   int Counter;

   for (Counter = 0 ; Counter < MAXPODS ; Counter ++)
   {
      ReturnPODList[Counter] = PODs[Counter];
   }
   return(0);
}

POD *PODEnv::FindPODByType(int PodType, int Number)
{
   int Counter;
   int PODCounter;

   PODCounter = 0;

   for (Counter = 0 ; Counter < MAXPODS ; Counter ++)
   {
      if (PODs[Counter]->GetType() == PodType)
      {
         PODCounter ++;
         if (Number == PODCounter)
         {
            return(PODs[Counter]);
         }
      }
   }
   return(NULL);
}

POD *PODEnv::FindPODByName(int PodType, char *TestName)
{
   int Counter;
   char TempName[POD_SIZE_NAME + 1];

   for (Counter = 0 ; Counter < MAXPODS ; Counter ++)
   {
      if (PODs[Counter]->GetType() == PodType)
      {
         PODs[Counter]->GetName(TempName);
         if (!strncmp(TestName, TempName, POD_SIZE_NAME))
         {
            return(dynamic_cast<POD *> (PODs[Counter]));
         }
      }
   }
   return(NULL);
}

POD *PODEnv::GetPOD(int Number)
{
   return(PODs[Number]);
}

int PODEnv::RefreshPOD(int Number)
{
   int TempType;

   if (PODs[Number] != NULL) delete(PODs[Number]);

   PODs[Number] = new POD(Number);
   TempType = PODs[Number]->GetType();
   if (PODs[Number]->IsValid())
   {
      NumberOfPODs ++;
#if DEBUG > 2
      PODs[Number]->DisplayPODInfo();
#endif
      switch (TempType)
      {
         case POD_TYPE_THERMOMETER:
            delete PODs[Number];
            PODs[Number] = new ThermometerPOD(Number);
            break;
         case POD_TYPE_ALARM:
            delete PODs[Number];
            PODs[Number] = new AlarmPOD(Number);
            break;
         case POD_TYPE_MOTORCONTROL:
            delete PODs[Number];
            PODs[Number] = new MotorControlPOD(Number);
            break;
         case POD_TYPE_LIGHTSENSOR:
            delete PODs[Number];
            PODs[Number] = new LightSensorPOD(Number);
            break;
         case POD_TYPE_LIGHT:
            delete PODs[Number];
            PODs[Number] = new LightPOD(Number);
            break;
         case POD_TYPE_POWERSENSOR:
            delete PODs[Number];
            PODs[Number] = new PowerSensorPOD(Number);
            break;
         case POD_TYPE_COMPASS:
            delete PODs[Number];
            PODs[Number] = new CompassPOD(Number);
            break;
         case POD_TYPE_DISTANCE:
            delete PODs[Number];
            PODs[Number] = new SonarPOD(Number);
            break;
         case POD_TYPE_BUTTONS:
            delete PODs[Number];
            PODs[Number] = new ButtonsPOD(Number);
            break;
         default:
            break;
      }
   }
   else /* POD does not exist */
   {
   //         printf("Device %d is not a POD\n", Counter);
   //         delete(PODs[Counter]);
   //         PODs[Counter] = NULL;
   }
   return(0);
}

int PODEnv::RefreshPODs()
{
   int Counter;

   NumberOfPODs = 0;

   DisplayStatus(1, 0);
   for (Counter = 0 ; Counter < MAXPODS ; Counter ++)
   {
//      if (Verbosity == 1)
//      {
//         printf("%02d\b\b", Counter);
//         fflush(stdout);
//      }
      DisplayStatus(1, Counter);
      RefreshPOD(Counter);
   }
   DisplayStatus(1, MAXPODS);
   DisplayStatus(0, MAXPODS);
   return(0);
}

int PODEnv::ResetNumberOfPODs()
{
   NumberOfPODs = 0;
   return(0);
}

int PODEnv::DisplayStatus(int Status, int CurrentPODNumber)
{
   double ProgressValue;

   if (Options & POD_ENV_OPTION_TEXT_STATUS)
   {
      if (Status == 0) /* hide display */
      {
         printf("\r");
         fflush(stdout);
      }
      else if (Status == 1) /* display */
      {
         if (CurrentPODNumber == 0) ProgressValue = 0.0;
         else if (CurrentPODNumber >= MAXPODS) ProgressValue = 1.0;
         else ProgressValue = (CurrentPODNumber + 1.0) / (MAXPODS + 1.0);
         if (ProgressValue <= 1.0)
         {
            printf("Detecting PODs: %02d - %3.1lf%%\r", CurrentPODNumber, ProgressValue * 100.0 );
         }
         if (ProgressValue >= 1.0) printf("\nDetected %d PODs\n", NumberOfPODs);
         fflush(stdout);
      }
   }
   return(0);
}


