#include <stdio.h>
#include <ctype.h>

#include "ThermometerPOD.h"

ThermometerPOD::ThermometerPOD() : POD()
{
#if (DEBUG_OBJECTS)
   printf("In ThermometerPOD ()\n");
#endif
   PODType = POD_TYPE_THERMOMETER;
}

ThermometerPOD::ThermometerPOD(int DeviceNum,int PortNum) : POD(DeviceNum, PortNum)
{
#if (DEBUG_OBJECTS)
   printf("In ThermometerPOD (int, int)\n");
#endif
   if (PODType != POD_TYPE_THERMOMETER) printf("I'm not that type of POD\n");
}

ThermometerPOD::ThermometerPOD(int DeviceNum) : POD(DeviceNum)
{
#if (DEBUG_OBJECTS)
   printf("In ThermometerPOD (int)\n");
#endif
   if (PODType != POD_TYPE_THERMOMETER) printf("I'm not that type of POD\n");
}

int ThermometerPOD::GetTemperature(float &ReturnTemp)
{
   int Result;
   unsigned char Data[10];
   int Response;

   if (ReceiveReady()) ProcessAlert();
   SendCommand(POD_COMMAND_THERMOMETER_GET_TEMP);
   Result = ReceiveBytes(0x04, Data);
   Response = Data[0];
   ReturnTemp = ((Data[1] << 8) | Data[2]) + (Data[3] / 100.0);
   return(POD_ERROR_NONE);
}

int ThermometerPOD::GetUnits()
{
   int Result;
   unsigned char Data[10];
   int Response;

   if (ReceiveReady()) ProcessAlert();
   SendCommand(POD_COMMAND_THERMOMETER_GET_UNITS);
   Result = ReceiveBytes(0x02, Data);
   Response = Data[0];
   if (Response == POD_RESPONSE_ACK) return(Data[1]);
   return(POD_ERROR_BADRESPONSE);
}

int ThermometerPOD::SetUnits(char Units)
{
   int Result;
   unsigned char Data[10];
   int Response;

   if (ReceiveReady()) ProcessAlert();
   Units = toupper(Units);
   if (Units != 'C') Units = 'F';
   SendCommand(POD_COMMAND_THERMOMETER_SET_UNITS);
   Result = SendByte(Units);
   Result = ReceiveBytes(0x01, Data);
   Response = Data[0];
   if (Response == POD_RESPONSE_ACK) return(POD_ERROR_NONE);
   return(POD_ERROR_BADRESPONSE);
}

int ThermometerPOD::ProcessAlert()
{
   int Result;
   unsigned char Data[10];
   int Response;

   Result = ReceiveBytes(0x01, Data);
   Response = Data[0];
   if (Response == POD_RESPONSE_ALERT) printf("Got an alert\n");
   else printf("Got an unexpected byte: 0x%02X\n", Data[0]);

   return(0);
}

//ThermometerPOD *ThermometerPOD::operator=(const POD *Right)
//{
//   printf("Here\n");
//   return((ThermometerPOD *)(Right));
//}

int ThermometerPOD::Test()
{
   float Temperature;
   char Units;

   GetTemperature(Temperature);
   Units = GetUnits();
   printf("Temperature is %.2f %c\n", Temperature, Units);
   return(POD_ERROR_NONE);
}


